@@ -86,6 +86,51 @@ class TrailHistory():
 
         return diffs
 
+    def get_trajectories(self):
+        times, best_rewards, rewards = [0.0], [0.0], [0.0]
+        his = sorted(self.history, key=lambda t: t.trail_no)
+        best_trail_no = 0
+        best_elapsed = 0
+        for t in his:
+            rewards.append(t.reward)
+            times.append(t.elapsed + times[-1])
+
+            if t.reward > best_rewards[-1]:
+                best_rewards.append(t.reward)
+                best_trail_no = t.trail_no
+                best_elapsed = times[-1]
+            else:
+                best_rewards.append(best_rewards[-1])
+
+        return times, best_rewards, rewards, best_trail_no, best_elapsed
+
+    def save(self, filepath):
+        with open(filepath, 'w') as output:
+            output.write(f'{self.optimize_direction}\r\n')
+            for trail in self.history:
+                output.write(f'{trail.trail_no}|{trail.space_sample.vectors}|{trail.reward}|{trail.elapsed}\r\n')
+        return True
+
+    @staticmethod
+    def load_history(space_fn, filepath):
+        with open(filepath, 'r') as input:
+            line = input.readline()
+            history = TrailHistory(line.strip())
+            while line is not None and line != '':
+                line = input.readline()
+                if line.strip() == '':
+                    continue
+                fields = line.split('|')
+                assert len(fields) == 4, f'Trail format is not correct. \r\nline:[{line}]'
+                sample = space_fn()
+                vector = [float(n) if n.__contains__('.') else int(n) for n in
+                          fields[1].replace('[', '').replace(']', '').split(',')]
+                sample.assign_by_vectors(vector)
+                trail = Trail(space_sample=sample, trail_no=int(fields[0]), reward=float(fields[2]),
+                              elapsed=float(fields[3]))
+                history.append(trail)
+            return history
+
 
 class TrailStore(object):
     def __init__(self):
