@@ -7,7 +7,7 @@ from hypernets.frameworks.ml.common_ops import get_space_num_cat_pipeline_comple
 from hypernets.searchers.random_searcher import RandomSearcher
 from hypernets.core.callbacks import *
 from hypernets.core.searcher import OptimizeDirection
-from deeptables.datasets import dsutils
+from hypernets.frameworks.ml.datasets import dsutils
 from sklearn.model_selection import train_test_split
 from tests import test_output_dir
 
@@ -22,7 +22,7 @@ X_train, X_test = train_test_split(df, test_size=0.8, random_state=42)
 y_train = X_train.pop('y')
 y_test = X_test.pop('y')
 
-hk.search(X_train, y_train, X_test, y_test, max_trails=5)
+hk.search(X_train, y_train, X_test, y_test, max_trails=500)
 assert hk.best_model
 best_trial = hk.get_best_trail()
 print(f'best_train:{best_trial}')
